Struct Dlycr
#[repr(transparent)]pub struct Dlycr(pub u32);Expand description
This register is used for the adjustment stream delays.
Tuple Fields
0: u32Implementations
impl Dlycr
impl Dlycr
pub const fn skpdly(&self) -> u8
pub const fn skpdly(&self) -> u8
Delay to apply to a bitstream Set and cleared by software. Defines the number of input samples that will be skipped. Skipping is applied immediately after writing to this field, if SKPBF = 0 , and the corresponding bit DFLTEN = 1 . If SKPBF = 1 the value written into the register is ignored by the delay state machine. - 0: No input sample skipped, - 1: 1 input sample skipped, … - 127: 127 input sample skipped,.
pub const fn set_skpdly(&mut self, val: u8)
pub const fn set_skpdly(&mut self, val: u8)
Delay to apply to a bitstream Set and cleared by software. Defines the number of input samples that will be skipped. Skipping is applied immediately after writing to this field, if SKPBF = 0 , and the corresponding bit DFLTEN = 1 . If SKPBF = 1 the value written into the register is ignored by the delay state machine. - 0: No input sample skipped, - 1: 1 input sample skipped, … - 127: 127 input sample skipped,.
pub const fn skpbf(&self) -> bool
pub const fn skpbf(&self) -> bool
Skip Busy flag Set and cleared by hardware. Shall be used in order to control if the delay sequence is completed. - 0: Reading 0 means that the MDF is ready to accept a new value into SKPDLY[6:0]. - 1: Reading 1 means that last valid SKPDLY[6:0] is still under precessing.
pub const fn set_skpbf(&mut self, val: bool)
pub const fn set_skpbf(&mut self, val: bool)
Skip Busy flag Set and cleared by hardware. Shall be used in order to control if the delay sequence is completed. - 0: Reading 0 means that the MDF is ready to accept a new value into SKPDLY[6:0]. - 1: Reading 1 means that last valid SKPDLY[6:0] is still under precessing.